@@ -1,13 +1,12 @@
 import os
 import ssl
 import typing
-import warnings
 from base64 import b64encode
 from pathlib import Path
 
 from ._models import URL, Headers
 from ._types import CertTypes, HeaderTypes, TimeoutTypes, URLTypes, VerifyTypes
-from ._utils import get_ca_bundle_from_env, get_logger, warn_deprecated
+from ._utils import get_ca_bundle_from_env, get_logger
 
 DEFAULT_CIPHERS = ":".join(
     [
@@ -42,7 +41,7 @@ UNSET = UnsetType()
 def create_ssl_context(
     cert: CertTypes = None,
     verify: VerifyTypes = True,
-    trust_env: bool = None,
+    trust_env: bool = True,
     http2: bool = False,
 ) -> ssl.SSLContext:
     return SSLConfig(
@@ -62,7 +61,7 @@ class SSLConfig:
         *,
         cert: CertTypes = None,
         verify: VerifyTypes = True,
-        trust_env: bool = None,
+        trust_env: bool = True,
         http2: bool = False,
     ):
         self.cert = cert
@@ -210,44 +209,7 @@ class Timeout:
         read: typing.Union[None, float, UnsetType] = UNSET,
         write: typing.Union[None, float, UnsetType] = UNSET,
         pool: typing.Union[None, float, UnsetType] = UNSET,
-        # Deprecated aliases.
-        connect_timeout: typing.Union[None, float, UnsetType] = UNSET,
-        read_timeout: typing.Union[None, float, UnsetType] = UNSET,
-        write_timeout: typing.Union[None, float, UnsetType] = UNSET,
-        pool_timeout: typing.Union[None, float, UnsetType] = UNSET,
     ):
-        if not isinstance(connect_timeout, UnsetType):
-            warn_deprecated(
-                "httpx.Timeout(..., connect_timeout=...) is deprecated and will "
-                "raise errors in a future version. "
-                "Use httpx.Timeout(..., connect=...) instead."
-            )
-            connect = connect_timeout
-
-        if not isinstance(read_timeout, UnsetType):
-            warn_deprecated(
-                "httpx.Timeout(..., read_timeout=...) is deprecated and will "
-                "raise errors in a future version. "
-                "Use httpx.Timeout(..., write=...) instead."
-            )
-            read = read_timeout
-
-        if not isinstance(write_timeout, UnsetType):
-            warn_deprecated(
-                "httpx.Timeout(..., write_timeout=...) is deprecated and will "
-                "raise errors in a future version. "
-                "Use httpx.Timeout(..., write=...) instead."
-            )
-            write = write_timeout
-
-        if not isinstance(pool_timeout, UnsetType):
-            warn_deprecated(
-                "httpx.Timeout(..., pool_timeout=...) is deprecated and will "
-                "raise errors in a future version. "
-                "Use httpx.Timeout(..., pool=...) instead."
-            )
-            pool = pool_timeout
-
         if isinstance(timeout, Timeout):
             # Passed as a single explicit Timeout.
             assert connect is UNSET
@@ -276,13 +238,10 @@ class Timeout:
             self.pool = pool
         else:
             if isinstance(timeout, UnsetType):
-                warnings.warn(
+                raise ValueError(
                     "httpx.Timeout must either include a default, or set all "
-                    "four parameters explicitly. Omitting the default argument "
-                    "is deprecated and will raise errors in a future version.",
-                    DeprecationWarning,
+                    "four parameters explicitly."
                 )
-                timeout = None
             self.connect = timeout if isinstance(connect, UnsetType) else connect
             self.read = timeout if isinstance(read, UnsetType) else read
             self.write = timeout if isinstance(write, UnsetType) else write
@@ -333,46 +292,32 @@ class Limits:
         *,
         max_connections: int = None,
         max_keepalive_connections: int = None,
-        # Deprecated parameter naming, in favour of more explicit version:
-        max_keepalive: int = None,
+        keepalive_expiry: typing.Optional[float] = 5.0,
     ):
-        if max_keepalive is not None:
-            warnings.warn(
-                "'max_keepalive' is deprecated. Use 'max_keepalive_connections'.",
-                DeprecationWarning,
-            )
-            max_keepalive_connections = max_keepalive
-
         self.max_connections = max_connections
         self.max_keepalive_connections = max_keepalive_connections
+        self.keepalive_expiry = keepalive_expiry
 
     def __eq__(self, other: typing.Any) -> bool:
         return (
             isinstance(other, self.__class__)
             and self.max_connections == other.max_connections
             and self.max_keepalive_connections == other.max_keepalive_connections
+            and self.keepalive_expiry == other.keepalive_expiry
         )
 
     def __repr__(self) -> str:
         class_name = self.__class__.__name__
         return (
             f"{class_name}(max_connections={self.max_connections}, "
-            f"max_keepalive_connections={self.max_keepalive_connections})"
+            f"max_keepalive_connections={self.max_keepalive_connections}, "
+            f"keepalive_expiry={self.keepalive_expiry})"
         )
 
 
-class PoolLimits(Limits):
-    def __init__(self, **kwargs: typing.Any) -> None:
-        warn_deprecated(
-            "httpx.PoolLimits(...) is deprecated and will raise errors in the future. "
-            "Use httpx.Limits(...) instead."
-        )
-        super().__init__(**kwargs)
-
-
 class Proxy:
     def __init__(
-        self, url: URLTypes, *, headers: HeaderTypes = None, mode: str = "DEFAULT",
+        self, url: URLTypes, *, headers: HeaderTypes = None, mode: str = "DEFAULT"
     ):
         url = URL(url)
         headers = Headers(headers)
