@@ -1,19 +1,17 @@
 import codecs
-import collections
 import logging
 import mimetypes
 import netrc
 import os
 import re
 import sys
+import time
 import typing
-import warnings
-from datetime import timedelta
 from pathlib import Path
-from time import perf_counter
-from types import TracebackType
 from urllib.request import getproxies
 
+import sniffio
+
 from ._types import PrimitiveData
 
 if typing.TYPE_CHECKING:  # pragma: no cover
@@ -30,14 +28,19 @@ _HTML5_FORM_ENCODING_RE = re.compile(
 
 
 def normalize_header_key(
-    value: typing.Union[str, bytes], encoding: str = None
+    value: typing.Union[str, bytes],
+    lower: bool,
+    encoding: str = None,
 ) -> bytes:
     """
     Coerce str/bytes into a strictly byte-wise HTTP header key.
     """
     if isinstance(value, bytes):
-        return value.lower()
-    return value.encode(encoding or "ascii").lower()
+        bytes_value = value
+    else:
+        bytes_value = value.encode(encoding or "ascii")
+
+    return bytes_value.lower() if lower else bytes_value
 
 
 def normalize_header_value(
@@ -51,9 +54,9 @@ def normalize_header_value(
     return value.encode(encoding or "ascii")
 
 
-def str_query_param(value: "PrimitiveData") -> str:
+def primitive_value_to_str(value: "PrimitiveData") -> str:
     """
-    Coerce a primitive data type into a string value for query params.
+    Coerce a primitive data type into a string value.
 
     Note that we prefer JSON-style 'true'/'false' for boolean values here.
     """
@@ -147,13 +150,11 @@ class NetRCInfo:
                     pass
         return self._netrc_info
 
-    def get_credentials(
-        self, authority: str
-    ) -> typing.Optional[typing.Tuple[str, str]]:
+    def get_credentials(self, host: str) -> typing.Optional[typing.Tuple[str, str]]:
         if self.netrc_info is None:
             return None
 
-        auth_info = self.netrc_info.authenticators(authority)
+        auth_info = self.netrc_info.authenticators(host)
         if auth_info is None or auth_info[2] is None:
             return None
         return (auth_info[0], auth_info[2])
@@ -367,53 +368,35 @@ def peek_filelike_length(stream: typing.IO) -> int:
         return os.fstat(fd).st_size
 
 
-def flatten_queryparams(
-    queryparams: typing.Mapping[
-        str, typing.Union["PrimitiveData", typing.Sequence["PrimitiveData"]]
-    ]
-) -> typing.List[typing.Tuple[str, "PrimitiveData"]]:
-    """
-    Convert a mapping of query params into a flat list of two-tuples
-    representing each item.
+class Timer:
+    async def _get_time(self) -> float:
+        library = sniffio.current_async_library()
+        if library == "trio":
+            import trio
 
-    Example:
-    >>> flatten_queryparams_values({"q": "httpx", "tag": ["python", "dev"]})
-    [("q", "httpx), ("tag", "python"), ("tag", "dev")]
-    """
-    items = []
+            return trio.current_time()
+        elif library == "curio":  # pragma: nocover
+            import curio
 
-    for k, v in queryparams.items():
-        if isinstance(v, collections.abc.Sequence) and not isinstance(v, (str, bytes)):
-            for u in v:
-                items.append((k, u))
-        else:
-            items.append((k, typing.cast("PrimitiveData", v)))
+            return await curio.clock()
 
-    return items
+        import asyncio
 
+        return asyncio.get_event_loop().time()
 
-class ElapsedTimer:
-    def __init__(self) -> None:
-        self.start: float = perf_counter()
-        self.end: typing.Optional[float] = None
+    def sync_start(self) -> None:
+        self.started = time.perf_counter()
 
-    def __enter__(self) -> "ElapsedTimer":
-        self.start = perf_counter()
-        return self
+    async def async_start(self) -> None:
+        self.started = await self._get_time()
 
-    def __exit__(
-        self,
-        exc_type: typing.Type[BaseException] = None,
-        exc_value: BaseException = None,
-        traceback: TracebackType = None,
-    ) -> None:
-        self.end = perf_counter()
+    def sync_elapsed(self) -> float:
+        now = time.perf_counter()
+        return now - self.started
 
-    @property
-    def elapsed(self) -> timedelta:
-        if self.end is None:
-            return timedelta(seconds=perf_counter() - self.start)
-        return timedelta(seconds=self.end - self.start)
+    async def async_elapsed(self) -> float:
+        now = await self._get_time()
+        return now - self.started
 
 
 class URLPattern:
@@ -462,12 +445,11 @@ class URLPattern:
         from ._models import URL
 
         if pattern and ":" not in pattern:
-            warn_deprecated(
+            raise ValueError(
                 f"Proxy keys should use proper URL forms rather "
                 f"than plain scheme strings. "
                 f'Instead of "{pattern}", use "{pattern}://"'
             )
-            pattern += "://"
 
         url = URL(pattern)
         self.pattern = pattern
@@ -525,7 +507,3 @@ class URLPattern:
 
     def __eq__(self, other: typing.Any) -> bool:
         return isinstance(other, URLPattern) and self.pattern == other.pattern
-
-
-def warn_deprecated(message: str) -> None:  # pragma: nocover
-    warnings.warn(message, DeprecationWarning, stacklevel=2)
